macro_rules! deps {
($(#[$meta:meta])* struct $name:ident {$($field:ident: $ty:ty,)*}) => { ... };
}Expand description
Generate a struct where all fields are wrapped in Layer
macro_rules! deps {
($(#[$meta:meta])* struct $name:ident {$($field:ident: $ty:ty,)*}) => { ... };
}Generate a struct where all fields are wrapped in Layer