Various helpers for viewing layers and their data without knowing the exact structure and contents
Enums
- Debug
Content - An debug element of a chunk
Traits
- Debug
- Runtime representation of any chunk type. It is perfectly valid to not return anything if the data is not useful for debug views.
- DynLayer
- Can point to any layer and allows programatic access to dependencies and chunks. Implemented for Layer. You should implement this if you manually implement Dependencies.