pub trait DynLayer {
// Required methods
fn iter_all_loaded(
&self,
) -> Box<dyn Iterator<Item = (Bounds, Box<dyn Debug + 'static>)> + '_>;
fn deps(&self) -> Vec<&dyn DynLayer>;
fn ident(&self) -> (usize, TypeId);
fn name(&self) -> String;
}Expand description
Can point to any layer and allows programatic access to dependencies and chunks. Implemented for Layer. You should implement this if you manually implement Dependencies.
Required Methods
Sourcefn iter_all_loaded(
&self,
) -> Box<dyn Iterator<Item = (Bounds, Box<dyn Debug + 'static>)> + '_>
fn iter_all_loaded( &self, ) -> Box<dyn Iterator<Item = (Bounds, Box<dyn Debug + 'static>)> + '_>
Iterate only over the chunks that have been generated already and not unloaded yet to make space for new ones.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".